# Ensure all providers are registered by importing their modules
import janito.providers.openai.provider
import janito.providers.google.provider
import janito.providers.azure_openai.provider
import janito.providers.anthropic.provider
import janito.providers.deepseek.provider
import janito.providers.moonshot.provider
import janito.providers.alibaba.provider
import janito.providers.zai.provider
import janito.providers.cerebras.provider
import janito.providers.mistral.provider
import janito.providers.ibm.provider

# Registration is now handled by each provider module to avoid circular imports
