# pragma: allowlist secret
translations = {
    "36107ed78ab25f6fb12ad8ce13018cd1ce6735d1": "Avvio del server web...",
    "70a0d194687568a47aa617fd85036ace1e69a982": "Vuoi davvero uscire? (s/n): ",
    "5c9ebcbbd7632ecb328bd52958b17158afaa32c6": "F12 = Azione Rapida (segue l'azione raccomandata)",
    "fe21121e2934234b68d19b2757532117d440c1e3": "Chiave API non trovata. Si prega di configurare 'api_key' nel file di configurazione.",
    "c9e3759b1756eba35b381ce2b72cd659e132b01f": "Ciao, {name}!",
    "ca1fee2f55baabdc2e4b0e9529c89ee024e62079": "Nessun prompt fornito nei messaggi",
    "f7449d23d0c500ae2a0b31e04f92b47a4d8ae845": "max_tokens deve essere un intero, ricevuto: {resolved_max_tokens!r}",
    "70a9ed8edb6da12e208431a31aa16ba54419b26f": "Risposta non valida/malformed da OpenAI (tentativo {attempt}/{max_retries}). Riprovo tra {wait_time} secondi...",
    "a873085e3b06184fb5d27e842f97b06b6190976d": "Numero massimo di tentativi per risposta non valida raggiunto. Generazione errore.",
    "66a34568bbe846bb1bde3619eb4d6dfa10211104": "L'API non supporta l'uso degli strumenti.",
    "09b81476b75586da4116b83f8be70d77b174cec3": "Limite di richieste API OpenAI (429) (tentativo {attempt}/{max_retries}): {e}. Riprovo tra {wait_time} secondi...",
    "5717a35dd2a1533fb7e15edc8c9329cb69f3410b": "Errore server API OpenAI (tentativo {attempt}/{max_retries}): {e}. Riprovo tra {wait_time} secondi...",
    "02e760ba15ed863176c1290ac8a9b923963103cd": "Errore client API OpenAI {status_code}: {e}. Nessun nuovo tentativo.",
    "2e52b0bbc8f16226b70e3e20f95c9245d2bcdb47": "Errore API OpenAI (tentativo {attempt}/{max_retries}): {e}. Riprovo tra {wait_time} secondi...",
    "012cc970e039fdd79c452fc676202c814ffc76ae": "Numero massimo di tentativi per errore API OpenAI raggiunto. Generazione errore.",
    "d0438e45667d31e0022b2497b5901cd4300f084b": "QueuedMessageHandler.handle_message si aspetta un dizionario con 'type' e 'message', ricevuto {msg_type}: {msg!r}",
    "9d3460187ffa19c7c8a4020157072b1087e1bd2f": "[QueuedMessageHandler] {msg_type}: {msg}",
    "3813833343430e8afa8fce33385c5e39fb24dd60": "[QueuedMessageHandler] {msg_type}: {message}",
    "0be9a22226e16a40797010d23a0f581542dca40e": "[ToolExecutor] {tool_name} chiamato con argomenti: {args}",
    "42c68edcb25442f518b1af77c6a2ddc07461aae0": "[ToolExecutor] Motivo chiamata: {tool_call_reason}",
    "002ff598115d84595ffeee6219cb5c03d3a1d4a6": "Domanda",
    "35747d13dcd91e8e8790c7f767d5ed764f541b9e": "procedi",
    "33dde3a1afbc418768a69fa53168d9b0638fe1aa": "avanti",
    "eee0bbba4ff92adbeb038a77df0466d660f15716": "continua",
    "edee9402d198b04ac77dcf5dc9cc3dac44573782": "prossimo",
    "8fdb7e2fa84f4faf0d9b92f466df424ec47a165b": "ok",
    "5f8f924671cda79b5205a6bf1b776f347c4a7a07": "Opzioni di configurazione disponibili:\n",
    "cef780a309cd234750764d42697882c24168ddab": "{key:15} {desc} (predefinito: {default})",
    "68c2cc7f0ceaa3e499ecb4db331feb4debbbcc23": "Modello",
    "c3f104d1365744b538bfde9f4adb6a6df4b80355": "Funzione",
    "99a0efc6cfd85d8ff2732a6718140f822cb90472": "Stile",
    "f1702b4686278becffc88baabe6f4b7a8355532c": "Messaggi",
    "c38c6c1f3a2743f8626703abb302e403d20ff81c": "Token",
    "a817d7eb8e0f1dab755ab5203a082e5c3c094fce": "Prompt",
    "2ff255684a2277f806fcebf3fe338ed27857f350": "Completamento",
    "b25928c69902557b0ef0a628490a3a1768d7b82f": "Totale",
    "76e63d65c883ed50df40ac3aeef0c2d6a1c4ad60": "Azione Rapida",
    "5397e0583f14f6c88de06b1ef28f460a1fb5b0ae": "Sì",
    "816c52fd2bdd94a63cd0944823a6c0aa9384c103": "No",
    "c47ae15370cfe1ed2781eedc1dc2547d12d9e972": "Aiuto",
    "cc3dbd47e1cf9003a55d3366b3adbcd72275e525": "Nuovo Task",
    "efa5a8b84e1afe65c81ecfce28c398c48f19ddc2": "Benvenuto su Janito{version_str}! Modalità chat attiva. Digita /exit per uscire.",
    "b314d6e1460f86e0f21abc5aceb7935a2a0667e8": "Benvenuto su Janito{version_str} in modalità [white on magenta]VANILLA[/white on magenta]! Strumenti, prompt di sistema e temperatura sono disattivati, a meno che non siano sovrascritti.",
}
